@@ -281,6 +281,8 @@ public class DriverWrapper extends Driver {
         public void addGeometries(Connection conn) throws SQLException {
             PGConnection pgconn = (PGConnection) conn;
             pgconn.addDataType("geometry", org.postgis.PGgeometry.class);
+            pgconn.addDataType("public.geometry", org.postgis.PGgeometry.class);
+            pgconn.addDataType("\"public\".\"geometry\"", org.postgis.PGgeometry.class);
         }
 
         public void addBoxen(Connection conn) throws SQLException {
@@ -300,6 +302,8 @@ public class DriverWrapper extends Driver {
         public void addGeometries(Connection conn) throws SQLException {
             org.postgresql.PGConnection pgconn = (org.postgresql.PGConnection) conn;
             pgconn.addDataType("geometry", org.postgis.PGgeometry.class);
+            pgconn.addDataType("public.geometry", org.postgis.PGgeometry.class);
+            pgconn.addDataType("\"public\".\"geometry\"", org.postgis.PGgeometry.class);
         }
 
 		public void addBoxen(Connection conn) throws SQLException {
@@ -319,6 +323,8 @@ public class DriverWrapper extends Driver {
         public void addGeometries(Connection conn) throws SQLException {
             PGConnection pgconn = (PGConnection) conn;
             pgconn.addDataType("geometry", org.postgis.PGgeometry.class);
+            pgconn.addDataType("public.geometry", org.postgis.PGgeometry.class);
+            pgconn.addDataType("\"public\".\"geometry\"", org.postgis.PGgeometry.class);
         }
 
         public void addBoxen(Connection conn) throws SQLException {
